@@ -1,6 +1,6 @@
 package SPVM::Sys;
 
-our $VERSION = "0.490";
+our $VERSION = "0.491";
 
 1;
 
@@ -703,6 +703,50 @@ The length of \$stream_ref must be equal to 1. Otherwise an exception is thrown.
 
 Calls the L<open|SPVM::Sys::IO/"open"> method in the L<Sys::IO|SPVM::Sys::IO> class.
 
+=head2 say
+
+  static method say : int ($stream : Sys::IO::FileStream, $string : string);
+
+Calls the L</"print"> method adding C<\n> to the end of $string.
+
+=head2 STDIN
+
+  static method STDIN : Sys::IO::FileStream ();
+
+Calls the L<stdin|SPVM::Sys::IO/"stdin"> method in the L<Sys::IO|SPVM::Sys::IO> class.
+
+=head2 STDOUT
+
+  static method STDOUT : Sys::IO::FileStream ();
+
+Calls the L<stdout|SPVM::Sys::IO/"stdout"> method in the L<Sys::IO|SPVM::Sys::IO> class.
+
+=head2 STDERR
+
+  static method STDERR : Sys::IO::FileStream ();
+
+Calls the L<stderr|SPVM::Sys::IO/"stderr"> method in the L<Sys::IO|SPVM::Sys::IO> class.
+
+=head2 signal
+
+  static method signal : void ($signum : int, $handler_name : string);
+
+If $handler_name is "DEFAULT", $handler is set to the return value of the L<"SIG_DFL"|SPVM::Sys::Signal/"SIG_DFL"> method.
+
+If $handler_name is "IGNORE", $handler is set to the return value of the L<"SIG_IGN"|SPVM::Sys::Signal/"SIG_IGN"> method.
+
+And calls the L<signal|SPVM::Sys::Signal/"signal"> method in the L<Sys::Signal|SPVM::Sys::Signal> class.
+
+=head2 kill
+
+  static method kill : int ($sig : int, $pid : int);
+
+Calls the L<kill|SPVM::Sys::IO/"kill"> method in the L<Sys::Signal|SPVM::Sys::Signal> class.
+
+If succeed, returns 1.
+
+=head1 Modules
+
 =head2 Sys::Env
 
 =head4 L<Sys::Env|SPVM::Sys::Env>
