@@ -1344,9 +1344,10 @@ int32_t SPVM__Sys__IO__fcntl(SPVM_ENV* env, SPVM_VALUE* stack) {
     // Int
     if (command_arg_basic_type_id == SPVM_NATIVE_C_BASIC_TYPE_ID_INT_CLASS && command_arg_type_dimension == 0) {
       int32_t command_arg_int32 = env->get_field_int_by_name(env, stack, obj_command_arg, "value", &error_id, __func__, FILE_NAME, __LINE__);
+      
       if (error_id) { return error_id; }
       
-      ret = fcntl(fd, command, &command_arg_int32);
+      ret = fcntl(fd, command, command_arg_int32);
     }
     // A pointer class
     else if (env->is_pointer_class(env, stack, obj_command_arg)) {
