@@ -10,12 +10,12 @@ const char* FILE_NAME = "Sys/Socket/Sockaddr/In6.c";
 
 int32_t SPVM__Sys__Socket__Sockaddr__In6__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   struct sockaddr_in6* socket_address = env->new_memory_stack(env, stack, sizeof(struct sockaddr_in6));
 
-  void* obj_socket_address = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Sockaddr::In6", socket_address, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  void* obj_socket_address = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Sockaddr::In6", socket_address, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   stack[0].oval = obj_socket_address;
   
@@ -104,7 +104,7 @@ int32_t SPVM__Sys__Socket__Sockaddr__In6__set_sin6_flowinfo(SPVM_ENV* env, SPVM_
 
 int32_t SPVM__Sys__Socket__Sockaddr__In6__sin6_addr(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_self = stack[0].oval;
   
@@ -115,8 +115,8 @@ int32_t SPVM__Sys__Socket__Sockaddr__In6__sin6_addr(SPVM_ENV* env, SPVM_VALUE* s
   struct in6_addr* address_ret = env->new_memory_stack(env, stack, sizeof(struct in6_addr));
   *address_ret = address;
 
-  void* obj_address_ret = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In6_addr", address_ret, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  void* obj_address_ret = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In6_addr", address_ret, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   stack[0].oval = obj_address_ret;
   
